/********************************************************************
Copyright 2015  Martin Gräßlin <mgraesslin@kde.org>
Copyright 2015  Marco Martin <mart@kde.org>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) version 3, or any
later version accepted by the membership of KDE e.V. (or its
successor approved by the membership of KDE e.V.), which shall
act as a proxy defined in Section 6 of version 3 of the license.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*********************************************************************/
#ifndef KWAYLAND_SCREEN_MAP_H
#define KWAYLAND_SCREEN_MAP_H

#include <QObject>

#include <KWayland/Client/kwaylandclient_export.h>

struct zwp_screen_map_manager_v1;

namespace KWayland
{
namespace Client
{

class EventQueue;

class KWAYLANDCLIENT_EXPORT ScreenMap : public QObject
{
    Q_OBJECT
public:
    virtual ~ScreenMap();

    void setup(zwp_screen_map_manager_v1 *manager);
    operator zwp_screen_map_manager_v1*();
    operator zwp_screen_map_manager_v1*() const;
    QString screen_names();
    QString touch_ids();
    QString touch_product_vendor();
    void get_screen_names();
    void get_touch_ids();
    void get_touch_product_vendor(int touchId);
    void set_screen_map_status(int touchId, QString screenName);
    explicit ScreenMap(QObject *parent = nullptr);
    void setEventQueue(EventQueue *queue);
    void destroy();

Q_SIGNALS:
    void removed();
    void screenInfoChange();
    void touchInfoChange();
    void touchProductVendorChange();

private:
    class Private;
    QScopedPointer<Private> d;
};

}
}

#endif

